@@ -3,10 +3,10 @@ RustPlus, An API wrapper for interfacing with the Rust+ App API
 """
 
 from .api import RustSocket
-from .exceptions import ClientError, ImageError, ServerNotResponsiveError, ClientNotConnectedError, PrefixNotDefinedError, CommandsNotEnabledError, RustSocketDestroyedError
 from .commands import CommandOptions, Command
+from .exceptions import *
 
 __name__ = "rustplus"
 __author__ = "olijefferson"
-__version__ = "4.1.4"
+__version__ = "5.0.1"
 __support__ = "Discord: https://discord.gg/nQqJe8qvP8"
