@@ -2,34 +2,26 @@ class Error(Exception):
     """Base class for other exceptions"""
     pass
 
-class ClientError(Error):
-    """Raised when the client details are not valid"""
-    pass
-
-class ImageError(Error):
-    """Raised when the Returned Image Bytes are not valid"""
+class RateLimitError(Error):
+    """Raised When an issue with the ratelimit has occurred"""
     pass
 
 class ServerNotResponsiveError(Error):
     """Raised when the target Server is not online / Unavailable"""
     pass
 
-class ClientNotConnectedError(Error):
-    """Raised when the client is not connected to the server"""
+class CommandsNotEnabledError(Error):
+    """Raised when events are not enabled"""
+    pass
+
+class ResponseNotRecievedError(Error):
+    """Raised when a response has not been recieved from the server"""
     pass
 
 class PrefixNotDefinedError(Error):
     """Raised when a prefix is not given"""
     pass
 
-class CommandsNotEnabledError(Error):
-    """Raised when events are not enabled"""
+class ImageError(Error):
+    """Raised when the bytes received are not valid"""
     pass
-
-class RustSocketDestroyedError(Error):
-    """Raised when the RustSocket has had #terminate called and tries to reconnect"""
-    pass
-
-class RateLimitError(Error):
-    """Raised When an issue with the ratelimit has occurred"""
-    pass
\ No newline at end of file
